@@ -17,3 +17,14 @@ def require_folder(path: str) -> None:
     if dir:
         if not _os.path.isdir(dir):
             _os.makedirs(dir)
+
+
+def ask_bool(question: str) -> bool:
+    while True:
+        answer = input(question + " (y/n): ")
+        if answer == "y":
+            return True
+        elif answer == "n":
+            return False
+        else:
+            print("Please answer y or n.")
